@@ -26,7 +26,7 @@
 #include <KDirModel>
 #include <KDirLister>
 
-#include <Plasma/Package>
+#include <KPackage/Package>
 
 namespace CuttleFish {
 
@@ -35,14 +35,14 @@ class View : public QQuickView
     Q_OBJECT
 
 public:
-    explicit View(const QString &category, QCommandLineParser &parser, QWindow *parent = 0 );
-    ~View();
+    explicit View(const QString &category, QCommandLineParser &parser, QWindow *parent = nullptr);
+    ~View() override;
 
 Q_SIGNALS:
     void titleChanged(const QString&);
 
 private:
-    Plasma::Package m_package;
+    KPackage::Package m_package;
     QQuickItem* m_browserRootItem;
     KDirModel m_dirModel;
 };
