@@ -21,16 +21,16 @@
 
 #include "ktreeviewsearchline.h"
 
-#include <QtCore/QList>
-#include <QtCore/QTimer>
-#include <QtWidgets/QApplication>
-#include <QtGui/QContextMenuEvent>
-#include <QtWidgets/QHBoxLayout>
-#include <QtWidgets/QHeaderView>
-#include <QtWidgets/QLabel>
-#include <QtWidgets/QMenu>
-#include <QtWidgets/QToolButton>
-#include <QtWidgets/QTreeView>
+#include <QList>
+#include <QTimer>
+#include <QApplication>
+#include <QContextMenuEvent>
+#include <QHBoxLayout>
+#include <QHeaderView>
+#include <QLabel>
+#include <QMenu>
+#include <QToolButton>
+#include <QTreeView>
 
 #include <QDebug>
 #include <kiconloader.h>
@@ -84,7 +84,7 @@ void KTreeViewSearchLinePrivate::rowsInserted( QAbstractItemModel *model, const
   if ( !model )
     return;
 
-  QTreeView* widget = 0L;
+  QTreeView* widget = nullptr;
   foreach ( QTreeView* tree, treeViews )
     if ( tree->model() == model ) {
       widget = tree;
@@ -264,7 +264,7 @@ QTreeView *KTreeViewSearchLine::treeView() const
   if ( d->treeViews.count() == 1 )
     return d->treeViews.first();
   else
-    return 0;
+    return nullptr;
 }
 
 QList<QTreeView *> KTreeViewSearchLine::treeViews() const
@@ -400,12 +400,12 @@ bool KTreeViewSearchLine::itemMatches( const QModelIndex &index, int row, const
     QList<int>::ConstIterator it = d->searchColumns.constBegin();
     for ( ; it != d->searchColumns.constEnd(); ++it ) {
       if ( *it < columncount &&
-           index.child( row, *it ).data( Qt::DisplayRole ).toString().indexOf( pattern, 0, d->caseSensitive ) >= 0 )
+           index.model()->index( row, *it, index ).data( Qt::DisplayRole ).toString().indexOf( pattern, 0, d->caseSensitive ) >= 0 )
         return true;
     }
   } else {
     for ( int i = 0; i < columncount; ++i) {
-      if ( index.child( row, i ).data( Qt::DisplayRole ).toString().indexOf( pattern, 0, d->caseSensitive ) >= 0 )
+      if ( index.model()->index( row, i, index ).data( Qt::DisplayRole ).toString().indexOf( pattern, 0, d->caseSensitive ) >= 0 )
         return true;
     }
   }
@@ -549,8 +549,8 @@ class KTreeViewSearchLineWidgetPrivate
 {
   public:
     KTreeViewSearchLineWidgetPrivate()
-      : treeView( 0 ),
-        searchLine( 0 )
+      : treeView( nullptr ),
+        searchLine( nullptr )
     {
     }
 
