@@ -25,7 +25,6 @@
 #include <qcommandlineparser.h>
 #include <qcommandlineoption.h>
 #include <QQuickItem>
-#include <QtQml>
 
 #include <kpackage/package.h>
 #include <kpackage/packageloader.h>
@@ -42,13 +41,10 @@ int main(int argc, char **argv)
     QCommandLineParser parser;
     QApplication app(argc, argv);
 
-    const QString description = i18n("Plasma Look And Feel Explorer");
-    const char version[] = PROJECT_VERSION;
-
-    app.setApplicationVersion(version);
+    app.setApplicationVersion(PROJECT_VERSION);
     parser.addVersionOption();
     parser.addHelpOption();
-    parser.setApplicationDescription(description);
+    parser.setApplicationDescription(i18n("Plasma Look And Feel Explorer"));
 
     QCommandLineOption themeOption(QCommandLineOption(QStringList() << "l" << "lookandfeel", i18n("Look And Feel to open"), "lookandfeel"));
 
