@@ -57,13 +57,13 @@ public:
            PackageVersionRole = Qt::UserRole + 3
          };
 
-    ThemeListModel(QObject *parent = 0);
-    virtual ~ThemeListModel();
+    explicit ThemeListModel(QObject *parent = nullptr);
+    ~ThemeListModel() override;
 
-    virtual QHash<int, QByteArray> roleNames() const;
+    QHash<int, QByteArray> roleNames() const override;
 
-    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     QModelIndex indexOf(const QString &path) const;
     void reload();
     void clearThemeList();
